==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDockManagerPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebDockManagerPaneDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDockManagerPaneDescriptionMetadata extends Base {
        static b(a) {
            if (WebDockManagerPaneDescriptionMetadata.a == null) {
                WebDockManagerPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDockManagerPaneDescriptionMetadata.c(WebDockManagerPaneDescriptionMetadata.a);
            }
            if (a.k(WebDockManagerPaneDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDockManagerPaneDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DockManagerPane");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Name", "String");
        }
        static d(a) {
            WebDockManagerPaneDescriptionMetadata.b(a);
            a.ab("WebDockManagerPane", WebDockManagerPaneDescriptionMetadata.a);
        }
    }
    WebDockManagerPaneDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDockManagerPaneDescriptionMetadata, 'WebDockManagerPaneDescriptionMetadata');
    WebDockManagerPaneDescriptionMetadata.a = null;
    return WebDockManagerPaneDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebDockManagerPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebDockManagerPaneDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDockManagerPaneDescriptionMetadata extends Base {
        static b(a) {
            if (WebDockManagerPaneDescriptionMetadata.a == null) {
                WebDockManagerPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDockManagerPaneDescriptionMetadata.c(WebDockManagerPaneDescriptionMetadata.a);
            }
            if (a.k(WebDockManagerPaneDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDockManagerPaneDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DockManagerPane");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Name", "String");
        }
        static d(a) {
            WebDockManagerPaneDescriptionMetadata.b(a);
            a.ad("WebDockManagerPane", WebDockManagerPaneDescriptionMetadata.a);
        }
    }
    WebDockManagerPaneDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDockManagerPaneDescriptionMetadata, 'WebDockManagerPaneDescriptionMetadata');
    WebDockManagerPaneDescriptionMetadata.a = null;
    return WebDockManagerPaneDescriptionMetadata;
})();
